# Using test runner integrations

If you use nose or pytest to run tests, you can use native plugins to integrate with Launchable.

See their respective pages for instructions:

* [nose.md](../resources/integrations/nose.md "mention")
* [pytest.md](../resources/integrations/pytest.md "mention")

Otherwise, see [using-the-launchable-cli](using-the-launchable-cli/ "mention").
